@@ -98,6 +98,7 @@ class AssetMixin(ModelMixins):
         fields_manual=None,
         fields_regex=None,
         fields_default=True,
+        fields_root=None,
         fields_map=None,
         max_rows=None,
         max_pages=None,
@@ -156,6 +157,7 @@ class AssetMixin(ModelMixins):
             fields_regex=fields_regex,
             fields_default=fields_default,
             fields_map=fields_map,
+            fields_root=fields_root,
         )
 
         if sort_field:
@@ -507,21 +509,17 @@ class AssetMixin(ModelMixins):
         # XXX error if no OR / AND in pre & post
         return query
 
-    def _init(self, auth, **kwargs):
-        """Post init method for subclasses to use for extra setup.
-
-        Args:
-            auth (:obj:`.auth.Model`): object to use for auth and sending API requests
-        """
+    def _init(self, **kwargs):
+        """Post init method for subclasses to use for extra setup."""
         # cross reference
-        self.adapters = Adapters(auth=auth, **kwargs)
+        self.adapters = Adapters(auth=self.auth, **kwargs)
 
         # children
         self.labels = Labels(parent=self)
         self.saved_query = SavedQuery(parent=self)
         self.fields = Fields(parent=self)
 
-        super(AssetMixin, self)._init(auth=auth, **kwargs)
+        super(AssetMixin, self)._init(**kwargs)
 
     def _count(self, query=None, history_date=None):
         """Direct API method to get the count of assets.
