@@ -59,7 +59,7 @@ class ApiV1:
         cached="cached",
         count="count",
         views="views",
-        view_by_id="views/saved/{id}",
+        view_by_search_type="views/by-{search_type}/{value}",
         labels="labels",
         fields="fields",
         destroy="destroy",
@@ -74,7 +74,7 @@ class ApiV1:
         by_id="{id}",
         count="count",
         views="views",
-        view_by_id="views/saved/{id}",
+        view_by_search_type="views/by-{search_type}/{value}",
         labels="labels",
         fields="fields",
         destroy="destroy",
