@@ -1,25 +1,16 @@
 # -*- coding: utf-8 -*-
 """Command line interface for Axonius API Client."""
+import sys
+
 import click
 
 from .. import version
-from ..constants import (
-    LOG_FILE_MAX_FILES,
-    LOG_FILE_MAX_MB,
-    LOG_FILE_NAME,
-    LOG_FILE_PATH,
-    LOG_LEVEL_API,
-    LOG_LEVEL_AUTH,
-    LOG_LEVEL_CONSOLE,
-    LOG_LEVEL_FILE,
-    LOG_LEVEL_HTTP,
-    LOG_LEVEL_PACKAGE,
-    LOG_LEVELS_STR,
-    REQUEST_ATTR_MAP,
-    RESPONSE_ATTR_MAP,
-    TIMEOUT_CONNECT,
-    TIMEOUT_RESPONSE,
-)
+from ..constants import (LOG_FILE_MAX_FILES, LOG_FILE_MAX_MB, LOG_FILE_NAME,
+                         LOG_FILE_PATH, LOG_LEVEL_API, LOG_LEVEL_AUTH,
+                         LOG_LEVEL_CONSOLE, LOG_LEVEL_FILE, LOG_LEVEL_HTTP,
+                         LOG_LEVEL_PACKAGE, LOG_LEVELS_STR, REQUEST_ATTR_MAP,
+                         RESPONSE_ATTR_MAP, TIMEOUT_CONNECT, TIMEOUT_RESPONSE)
+from ..logs import LOG
 from . import context, grp_adapters, grp_assets, grp_system, grp_tools
 
 
@@ -328,6 +319,7 @@ def cli(
     quiet,
 ):
     """Command line interface for the Axonius API Client."""
+    LOG.debug(f"sys.argv: {sys.argv}")
     ctx._click_ctx = click_ctx
     ctx.QUIET = quiet
     ctx._connect_args["log_level_package"] = log_level_package
