@@ -7,6 +7,7 @@ import requests
 from .api.adapters import Adapters
 from .api.assets import Devices, Users
 from .api.enforcements import Enforcements
+from .api.enforcements.actions import RunAction
 from .api.system import System
 from .auth import ApiKey
 from .constants import (LOG_FILE_MAX_FILES, LOG_FILE_MAX_MB, LOG_FILE_NAME,
@@ -313,6 +314,18 @@ class Connect:
             self._enforcements = Enforcements(**self._api_args)
         return self._enforcements
 
+    @property
+    def run_actions(self):
+        """Get the object for run actions API.
+
+        Returns:
+            :obj:`axonius_api_client.actions.RunAction`
+        """
+        self.start()
+        if not hasattr(self, "_run_actions"):
+            self._run_actions = RunAction(**self._api_args)
+        return self._run_actions
+
     @property
     def system(self):
         """Get the object for system API.
